@@ -1,4 +1,5 @@
 from axes.handlers.base import AxesBaseHandler, AbstractAxesHandler
+from typing import Optional
 
 
 class AxesDummyHandler(AbstractAxesHandler, AxesBaseHandler):
@@ -6,7 +7,7 @@ class AxesDummyHandler(AbstractAxesHandler, AxesBaseHandler):
     Signal handler implementation that does nothing and can be used to disable signal processing.
     """
 
-    def is_allowed(self, request, credentials: dict = None) -> bool:
+    def is_allowed(self, request, credentials: Optional[dict] = None) -> bool:
         return True
 
     def user_login_failed(self, sender, credentials: dict, request=None, **kwargs):
@@ -18,5 +19,5 @@ class AxesDummyHandler(AbstractAxesHandler, AxesBaseHandler):
     def user_logged_out(self, sender, request, user, **kwargs):
         pass
 
-    def get_failures(self, request, credentials: dict = None) -> int:
+    def get_failures(self, request, credentials: Optional[dict] = None) -> int:
         return 0
