@@ -21,6 +21,20 @@ class AccessBase(models.Model):
         ordering = ["-attempt_time"]
 
 
+class AccessFailureLog(AccessBase):
+    locked_out = models.BooleanField(
+        _("Access lock out"), null=False, blank=True, default=False
+    )
+
+    def __str__(self):
+        locked_out_str = " locked out" if self.locked_out else ""
+        return f"Failed access: user {self.username}{locked_out_str} on {self.attempt_time} from {self.ip_address}"
+
+    class Meta:
+        verbose_name = _("access failure")
+        verbose_name_plural = _("access failures")
+
+
 class AccessAttempt(AccessBase):
     get_data = models.TextField(_("GET Data"))
 
